pyswarms.swarms package
=======================

This package contains the Swarm class for creating your own swarm
implementation. The class acts as a DataClass, holding information on the
particles you have generated throughout each timestep. It offers a pre-built
and flexible way of building your own swarm.

pyswarms.swarms class
-----------------------

.. autoclass:: pyswarms.backend.swarms.Swarm
   :members: